@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Test::Routine;
 # ABSTRACT: composable units of assertion
-$Test::Routine::VERSION = '0.022'; # TRIAL
+$Test::Routine::VERSION = '0.026'; # TRIAL
 #pod =head1 SYNOPSIS
 #pod
 #pod   # mytest.t
@@ -218,7 +218,7 @@ use Test::Routine::Common;
 use Test::Routine::Test;
 
 Moose::Exporter->setup_import_methods(
-  with_caller => [ qw(test) ],
+  as_is       => [ qw(test) ],
   also        => 'Moose::Role',
 );
 
@@ -234,7 +234,7 @@ sub init_meta {
 
 my $i = 0;
 sub test {
-  my $caller = shift;
+  my $caller = caller();
   my $name   = shift;
   my ($arg, $body);
 
@@ -266,8 +266,13 @@ sub test {
   my $method;
   if (blessed($body) && $body->isa('Class::MOP::Method')) {
     my $method_metaclass = Moose::Util::with_traits(
-      blessed($body), 'Test::Routine::Test::Role'
+      blessed($body),
+      'Test::Routine::Test::Role',
+      ($caller->can('test_routine_test_traits')
+        ? $caller->test_routine_test_traits
+        : ()),
     );
+
     $method = $method_metaclass->meta->rebless_instance(
       $body,
       %$arg,
@@ -275,9 +280,20 @@ sub test {
       package_name => $caller,
       _origin      => \%origin,
     );
-  }
-  else {
-    $method = Test::Routine::Test->wrap(
+  } else {
+    my $test_class = 'Test::Routine::Test';
+
+    if ($caller->can('test_routine_test_traits')) {
+      my @traits = $caller->test_routine_test_traits;
+
+      $test_class = Moose::Meta::Class->create_anon_class(
+        superclasses => [ $test_class ],
+        cache        => 1,
+        roles        => \@traits,
+      )->name;
+    }
+
+    $method = $test_class->wrap(
       %$arg,
       name => $name,
       body => $body,
@@ -312,7 +328,7 @@ Test::Routine - composable units of assertion
 
 =head1 VERSION
 
-version 0.022
+version 0.026
 
 =head1 SYNOPSIS
 
@@ -523,7 +539,7 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Alex White Dagfinn Ilmari Mannsåker Jesse Luehrs Yanick Champoux
+=for stopwords Alex White Dagfinn Ilmari Mannsåker gregor herrmann Jesse Luehrs Yanick Champoux
 
 =over 4
 
@@ -537,6 +553,10 @@ Dagfinn Ilmari Mannsåker <ilmari@ilmari.org>
 
 =item *
 
+gregor herrmann <gregoa@debian.org>
+
+=item *
+
 Jesse Luehrs <doy@tozt.net>
 
 =item *
