@@ -1,6 +1,6 @@
 package Test::Routine::Common;
 # ABSTRACT: a role composed by all Test::Routine roles
-$Test::Routine::Common::VERSION = '0.022'; # TRIAL
+$Test::Routine::Common::VERSION = '0.026'; # TRIAL
 use Moose::Role;
 
 #pod =head1 OVERVIEW
@@ -10,15 +10,28 @@ use Moose::Role;
 #pod
 #pod =cut
 
+use Test::Abortable 0.002 ();
 use Test2::API 1.302045 ();
 
 use namespace::autoclean;
 
+sub BUILD {
+}
+
+sub DEMOLISH {
+}
+
 sub run_test {
   my ($self, $test) = @_;
 
+  my $ctx = Test2::API::context();
+  my ($file, $line) = @{ $test->_origin }{ qw(file line) };
+  $ctx->trace->set_detail("at $file line $line");
+
   my $name = $test->name;
-  Test2::API::run_subtest($test->description, sub { $self->$name });
+  Test::Abortable::subtest($test->description, sub { $self->$name });
+
+  $ctx->release;
 }
 
 1;
@@ -35,7 +48,7 @@ Test::Routine::Common - a role composed by all Test::Routine roles
 
 =head1 VERSION
 
-version 0.022
+version 0.026
 
 =head1 OVERVIEW
 
